==> fdo-3.2.0.tar.gz: OpenSource_FDO/Fdo/Managed/Src/OSGeo/FDO/Commands/SpatialContext/mgSpatialContextExtentType.h <==
/*
* Copyright (C) 2004-2006  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*/

#pragma  once

BEGIN_NAMESPACE_OSGEO_FDO_COMMANDS_SPATIALCONTEXT

/// \brief
/// The FdoSpatialContextExtentType enumeration defines how the extent of
/// a context should be handled by the provider.
/// <param name="FdoSpatialContextExtentType_Static">
/// The spatial extent of the context is static and must be specified
/// when the context is created.
/// </param>
/// <param name="FdoSpatialContextExtentType_Dynamic">
/// The spatial extent of the context is dynamic and changes as data is
/// added and removed from the context.
/// </param>
public __value enum SpatialContextExtentType
{
    /// The spatial extent of the context is static and must be specified
    /// when the context is created. 
	SpatialContextExtentType_Static = FdoSpatialContextExtentType_Static,

    /// The spatial extent of the context is dynamic and changes as data is
    /// added and removed from the context. 
	SpatialContextExtentType_Dynamic = FdoSpatialContextExtentType_Dynamic
};

END_NAMESPACE_OSGEO_FDO_COMMANDS_SPATIALCONTEXT

==> fdo-3.2.2.tar.gz: OpenSource_FDO/Fdo/Managed/Src/OSGeo/FDO/Commands/SpatialContext/mgSpatialContextExtentType.h <==
/*
* Copyright (C) 2004-2006  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*/

#pragma  once

/// \cond DOXYGEN-IGNORE
BEGIN_NAMESPACE_OSGEO_FDO_COMMANDS_SPATIALCONTEXT
/// \endcond

/// \ingroup (OSGeoFDOCommandsSpatialContext)
/// \brief
/// The SpatialContextExtentType enumeration defines how the extent of
/// a context should be handled by the provider.
public __value enum SpatialContextExtentType
{
    /// The spatial extent of the context is static and must be specified
    /// when the context is created. 
	SpatialContextExtentType_Static = FdoSpatialContextExtentType_Static,

    /// The spatial extent of the context is dynamic and changes as data is
    /// added and removed from the context. 
	SpatialContextExtentType_Dynamic = FdoSpatialContextExtentType_Dynamic
};

/// \cond DOXYGEN-IGNORE
END_NAMESPACE_OSGEO_FDO_COMMANDS_SPATIALCONTEXT
/// \endcond
